@@ -1,7 +1,8 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#define INITIAL_TIMER_TIMEOUT 1500
+#define INITIAL_TIMER_TIMEOUT 1000
+#define MIN_INTERVAL 250
 
 #include <QMainWindow>
 #include <QVector>
@@ -28,11 +29,6 @@ public slots:
     void onColorClick(ColorButton::Color color);
     void onTimer();
 
-    void onBlueTimer();
-    void onOrangeTimer();
-    void onGreenTimer();
-    void onRedTimer();
-
 protected:
     void changeEvent(QEvent *e);
 
@@ -63,9 +59,6 @@ private:
     int score_;
     int hiscore_;
 
-    // Timers to shut down lights
-    QVector<QTimer*> shutdowntimers_;
-
     // Scores
     Number* nscore_;
     Number* nhiscore_;
